@@ -2,63 +2,12 @@
 
 import asyncio, sys
 from asyncio.subprocess import Process
-from pathlib import Path
-from typing import AnyStr
+from os import PathLike
+from utils_tddschn.git import git_get_current_branch, git_get_all_remotes
 
-PathLike = AnyStr | Path
-
-from git_pp import logger
+from . import logger
 
 
-# logger.add(sys.stdout,
-#            colorize=True,
-#            format="{level} <green>{time}</green> <level>{message}</level>")
-async def git_get_all_remotes(cwd: PathLike | None = None) -> list[str]:
-    program = ['git', 'remote']
-    proc: Process = await asyncio.create_subprocess_exec(
-        *program, stdout=asyncio.subprocess.PIPE, cwd=cwd)
-    logger.info(f'Getting all remotes of {cwd} .')
-    logger.info(f'Running: {program}')
-    # logger.info(f'Args: {proc.__dict__}')  # type: ignore
-    stdout, _ = await proc.communicate()
-    return stdout.decode().strip().splitlines()
-
-
-async def git_get_current_branch(cwd: PathLike | None = None) -> str:
-    program = ['git', 'branch', '--show-current']
-    proc: Process = await asyncio.create_subprocess_exec(
-        *program, stdout=asyncio.subprocess.PIPE, cwd=cwd)
-    stdout, _ = await proc.communicate()
-    return stdout.decode().strip()
-
-
-# async def git_push_to_remote(branch: str,
-#                              remote: str,
-#                              force=False,
-#                              timeout=None,
-#                              cwd: PathLike | None = None) -> tuple[int, str]:
-#     """pushes branch to remote named remote, and returns the return code
-
-#     Args:
-#         remote (str): name of the remote
-
-#     Returns:
-#         int: return code
-#     """
-#     program = ['git', 'push', remote, branch]
-#     if force:
-#         program.append('--force')
-#     process: Process = await asyncio.create_subprocess_exec(*program, cwd=cwd)
-#     print(f'Pushing {branch} to {remote}.')
-#     try:
-#         status_code = await asyncio.wait_for(process.wait(), timeout=timeout)
-#         # print(status_code)
-#     except asyncio.TimeoutError:
-#         print('Timed out waiting to finish, terminating...')
-#         process.terminate()
-#         status_code = await process.wait()
-#         # print(status_code)
-#     return (status_code, remote)
 
 
 async def git_push_to_remote(remote: str,
